Enum TonConnectPayloadSchema
pub enum TonConnectPayloadSchema {
Text {
text: String,
},
Binary {
bytes: Vec<u8>,
},
Cell {
schema_crc: u32,
cell: Cell,
},
}Expand description
Variants
Text
Text payload. Use this when the data is human-readable.
Binary
Binary payload. Use this when signing a hash, arbitrary bytes, or a file.
Cell
Cell payload. Use this if the signed data should be verifiable and restorable inside a smart contract.
Implementations
impl TonConnectPayloadSchema
impl TonConnectPayloadSchema
pub fn text(txt: impl Into<String>) -> TonConnectPayloadSchema
pub fn binary(bytes: impl Into<Vec<u8>>) -> TonConnectPayloadSchema
pub const fn cell(schema_crc: u32, cell: Cell) -> TonConnectPayloadSchema